@@ -6,17 +6,17 @@ from ts_t1_validator.validators.campaign_post_validator import CampaignPostValid
 
 
 class T1Validator:
-    def __init__(self, dto: Dict, t1_creds: Dict, validator_type="campaign"):
+    def __init__(self, t1_creds: Dict, validator_type="campaign"):
         self.validator = None
         t1_service = T1Service(t1_creds=t1_creds)
         if validator_type == "campaign":
-            self.validator = CampaignPostValidator(dto=dto, t1_service=t1_service)
+            self.validator = CampaignPostValidator(t1_service=t1_service)
         else:
             raise NotImplemented()
 
-    def validate(self):
+    def validate(self, dto: Dict):
         """
         Proxy validate method to proper class
         :return:
         """
-        return self.validator.validate()
+        return self.validator.validate(dto=dto)
